@@ -21,13 +21,20 @@ class PysvnDictBase(user_dict_base):
         user_dict_base.__init__( self, value_dict )
         self.__name = name
         if self.__name is None:
-            print( '%s given None as name' % self.__class__.__name__ )
+            print( '%s given None as name' % (self.__class__.__name__,) )
 
     def __getattr__( self, name ):
         if name in self.data:
             return self.data[ name ]
         raise AttributeError( "%s instance has no attribute '%s'" % (self.__class__.__name__, name) )
 
+    def _key( self ):
+        return self.__name
+
+    # make orderable for python3
+    def __lt__( self, other ):
+        return self._key() < other._key()
+
     def __repr__( self ):
         return '<%s %s>' % (self.__class__.__name__, repr(self.__name))
 
@@ -64,6 +71,10 @@ class PysvnWcInfo(PysvnDictBase):
     def __init__( self, value_dict ):
         PysvnDictBase.__init__( self, value_dict )
 
+class PysvnStatus2(PysvnDictBase):
+    def __init__( self, value_dict ):
+        PysvnDictBase.__init__( self, value_dict, value_dict.get( 'path', None ) )
+
 class PysvnStatus(PysvnDictBase):
     def __init__( self, value_dict ):
         PysvnDictBase.__init__( self, value_dict, value_dict.get( 'path', None ) )
@@ -72,6 +83,10 @@ class PysvnDiffSummary(PysvnDictBase):
     def __init__( self, value_dict ):
         PysvnDictBase.__init__( self, value_dict, value_dict.get( 'path', None ) )
 
+class PysvnCommitInfo(PysvnDictBase):
+    def __init__( self, value_dict ):
+        PysvnDictBase.__init__( self, value_dict )
+
 # An indication that you are interested in the @c kind field
 SVN_DIRENT_KIND        = 0x00001
 
@@ -133,11 +148,14 @@ class svn_err:
     bad_token = 125013
     bad_changelist_name = 125014
     bad_atomic = 125015
+    bad_compression_method = 125016
+    bad_property_value_eol = 125017
     xml_attrib_not_found = 130000
     xml_missing_ancestry = 130001
     xml_unknown_encoding = 130002
     xml_malformed = 130003
     xml_unescapable_data = 130004
+    xml_unexpected_element = 130005
     io_inconsistent_eol = 135000
     io_unknown_eol = 135001
     io_corrupt_eol = 135002
@@ -150,6 +168,7 @@ class svn_err:
     stream_malformed_data = 140001
     stream_unrecognized_data = 140002
     stream_seek_not_supported = 140003
+    stream_not_supported = 140004
     node_unknown_kind = 145000
     node_unexpected_kind = 145001
     entry_not_found = 150000
@@ -254,6 +273,20 @@ class svn_err:
     fs_incorrect_editor_completion = 160050
     fs_packed_revprop_read_failure = 160051
     fs_revprop_cache_init_failure = 160052
+    fs_malformed_txn_id = 160053
+    fs_index_corruption = 160054
+    fs_index_revision = 160055
+    fs_index_overflow = 160056
+    fs_container_index = 160057
+    fs_index_inconsistent = 160058
+    fs_lock_operation_failed = 160059
+    fs_unsupported_type = 160060
+    fs_container_size = 160061
+    fs_malformed_noderev_id = 160062
+    fs_invalid_generation = 160063
+    fs_corrupt_revprop_manifest = 160064
+    fs_corrupt_proplist = 160065
+    fs_ambiguous_checksum_rep = 160067
     repos_locked = 165000
     repos_hook_failure = 165001
     repos_bad_args = 165002
@@ -278,6 +311,7 @@ class svn_err:
     ra_repos_root_url_mismatch = 170010
     ra_session_url_mismatch = 170011
     ra_cannot_create_tunnel = 170012
+    ra_cannot_create_session = 170013
     ra_dav_sock_init = 175000
     ra_dav_creating_request = 175001
     ra_dav_request_failed = 175002
@@ -292,6 +326,8 @@ class svn_err:
     ra_dav_relocated = 175011
     ra_dav_conn_timeout = 175012
     ra_dav_forbidden = 175013
+    ra_dav_precondition_failed = 175014
+    ra_dav_method_not_allowed = 175015
     ra_local_repos_not_found = 180000
     ra_local_repos_open_failed = 180001
     svndiff_invalid_header = 185000
@@ -329,6 +365,7 @@ class svn_err:
     client_invalid_mergeinfo_no_mergetracking = 195021
     client_no_lock_token = 195022
     client_forbidden_by_server = 195023
+    client_conflict_option_not_applicable = 195024
     base = 200000
     plugin_load_failure = 200001
     malformed_file = 200002
@@ -368,6 +405,15 @@ class svn_err:
     too_many_memcached_servers = 200036
     malformed_version_string = 200037
     corrupted_atomic_storage = 200038
+    utf8proc_error = 200039
+    utf8_glob = 200040
+    corrupt_packed_data = 200041
+    composed_error = 200042
+    invalid_input = 200043
+    sqlite_rollback_failed = 200044
+    lz4_compression_failed = 200045
+    lz4_decompression_failed = 200046
+    canonicalization_failed = 200047
     cl_arg_parsing_error = 205000
     cl_insufficient_args = 205001
     cl_mutually_exclusive_args = 205002
@@ -380,6 +426,7 @@ class svn_err:
     cl_unnecessary_log_message = 205009
     cl_no_external_merge_tool = 205010
     cl_error_processing_externals = 205011
+    cl_repos_verify_failed = 205012
     ra_svn_cmd_err = 210000
     ra_svn_unknown_cmd = 210001
     ra_svn_connection_closed = 210002
@@ -389,6 +436,8 @@ class svn_err:
     ra_svn_bad_version = 210006
     ra_svn_no_mechanisms = 210007
     ra_svn_edit_aborted = 210008
+    ra_svn_request_size = 210009
+    ra_svn_response_size = 210010
     authn_creds_unavailable = 215000
     authn_no_provider = 215001
     authn_providers_exhausted = 215002
@@ -400,9 +449,31 @@ class svn_err:
     authz_invalid_config = 220003
     authz_unwritable = 220004
     diff_datasource_modified = 225000
+    diff_unexpected_data = 225001
     ra_serf_sspi_initialisation_failed = 230000
     ra_serf_ssl_cert_untrusted = 230001
     ra_serf_gssapi_initialisation_failed = 230002
     ra_serf_wrapped_error = 230003
+    ra_serf_stream_bucket_read_error = 230004
     assertion_fail = 235000
     assertion_only_tracing_links = 235001
+    asn1_out_of_data = 240000
+    asn1_unexpected_tag = 240001
+    asn1_invalid_length = 240002
+    asn1_length_mismatch = 240003
+    asn1_invalid_data = 240004
+    x509_feature_unavailable = 240005
+    x509_cert_invalid_pem = 240006
+    x509_cert_invalid_format = 240007
+    x509_cert_invalid_version = 240008
+    x509_cert_invalid_serial = 240009
+    x509_cert_invalid_alg = 240010
+    x509_cert_invalid_name = 240011
+    x509_cert_invalid_date = 240012
+    x509_cert_invalid_pubkey = 240013
+    x509_cert_invalid_signature = 240014
+    x509_cert_invalid_extensions = 240015
+    x509_cert_unknown_version = 240016
+    x509_cert_unknown_pk_alg = 240017
+    x509_cert_sig_mismatch = 240018
+    x509_cert_verify_failed = 240019
